#
# spec file for package pdfarranger
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020 Karl Cheng <qantas94heavy@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%define pythons python3
%else
%define pythons python311
%endif

Name:           pdfarranger
Version:        1.11.1
Release:        2.3
Summary:        Merge, split, rotate, crop, and rearrange pages of PDF documents
License:        GPL-3.0-only
URL:            https://github.com/pdfarranger/pdfarranger
Source:         https://github.com/pdfarranger/pdfarranger/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       %{python_flavor}-cairo
Requires:       %{python_flavor}-dateutil >= 2.4.0
Requires:       %{python_flavor}-gobject-Gdk
Requires:       %{python_flavor}-pikepdf >= 6
Requires:       gtk3
Requires:       typelib-1_0-Gtk-3_0
Requires:       typelib-1_0-Poppler-0_18
Recommends:     %{python_flavor}-img2pdf >= 0.3.4
BuildArch:      noarch

%description
pdfarranger is a small python-gtk application, which helps the user
to merge or split pdf documents and rotate, crop and rearrange their
pages using a graphical interface. It is a frontend for pikepdf.

pdfarranger is a fork of Konstantinos Poulios’s pdfshuffler. It is
a humble attempt to make the project a bit more active.

%lang_package

%prep
%autosetup -p1

%build
python%{python_bin_suffix} setup.py build

%install
python%{python_bin_suffix} setup.py install --prefix=%{_prefix} --root=%{buildroot}
%suse_update_desktop_file -r com.github.jeromerobert.pdfarranger Graphics VectorGraphics
%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{python_sitelib}/%{name}
%{python_sitelib}/%{name}-%{version}-py%{python_version}.egg-info
%{_datadir}/applications/com.github.jeromerobert.pdfarranger.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/%{name}
%{_datadir}/icons/hicolor
%{_datadir}/metainfo/com.github.jeromerobert.pdfarranger.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Wed Feb 19 2025 ecsos <ecsos@opensuse.org>
- Use pythons so we can build also for Leap with python311.
* Thu Oct 17 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.11.1
  * Fix slow saving on Windows when language set to Chinese,
    Greek, Hebrew, Japanese, Korean and possibly other
  * Add Arabic translation
  * Update Dutch translation
* Thu Aug  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.11.0
  New / improved features:
  * Preserve outlines and links when possible
  * Implement a GUI for hiding of margins
  * Implement a GUI for visually setting crop
  * Improve GUI for pasting of overlay and underlay
  * Improve zoom-fit toggle
  * Implement copying of text and image from PDF
  * Add a keyboard shortcut to open the popup menu
  * Show content loss warning on start & and link to user manual
  * Improve visual layout of headerbar title
  * Fix reversed file import order on Windows
  * Use cropped page size in "Page size" dialog
  * Drop PikePDF < 6 support
  Fixes:
  * Fix iconview in right-to-left locale
  * Fix too high scroll speed with high-resolution mouses
  * Fix a "raise KeyError(key) from None" in pikepdf
  * Fix crop white border
  * Fix handling of scaling and rotation at printing
  * Fix missing icon when running under Wayland
  * Fix failure when generating booklet with pikepdf v9
  * Fix issue when resizing a page with pikepdf v9
* Sun Dec 24 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.10.1
  * Fix for Python 3.12
* Mon Sep  4 2023 Cimbali <me@cimba.li>
- Update to 1.10.0
  * No longer use python-distutils-extra (#853, #859)
  * Add support for merging pages (#847, #440)
  * Add support for pasting a page as overlay & underlay (#832,
    [#530], #839)
  * Scroll the view after deleting pages (#501, #821)
  * Scroll horizontally with shift + mouse scroll wheel (#816,
    [#811])
  * Fix unit/scaling issue when printing on Windows (#809, #806)
  * Show config file location in preferences dialog (#852)
  * Add a dialog where language can be selected (#706, #779, #849,
    [#852])
  * Allow to force dark or light theme in the preferences (#788)
  * No longer forget file name to save when closing window (#744)
  * Improve multi-export workflow (#758, #760, #782, #794)
* Tue Nov 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.9.2
  * Fix "export all to individual files" overwrite
  * Fix unexpected application close and quit
  * Fix buggy export when CropBox is larger than MediaBox
  * Fix equal page size test in generate booklet
  * Fix NAME in man page
  * Some translation fixes
* Wed Oct 12 2022 C J <c.j@tuta.io>
- Update to 1.9.1:
  * Support for PikePDF 6 and so qpdf 11 (#716)
  * Fix a bug in booklet creation (#720)
  * Some translation update
- Version 1.9.0
  * Many improvements and fixes in the icon view (#505, #506, #612,
    [#629], #632, #637, #654, #670)
  * Remember previous file chooser location (#508)
  * Add close and open actions (#581, #593, #597)
  * Increase I/O performance and responsiveness (#542, #623)
  * Add option to set language in Windows (#578)
  * Add support for pasting an image from clipboard (#675)
  * Pan the view when pressing mouse wheel and moving mouse (#677)
  * Add fullscreen mode (#665)
  * Allow to print the document (#647)
  * Require GTK >= 3.20 because of a new file chooser on Windows
    (#704)
  * State that pikepdf 6 is not yet supported (#716)
* Tue Sep 13 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add missing typelib-1_0-Gtk-3_0 requirement
* Sun Mar 20 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.8.2:
  * Fix 2 bugs in scaled pages export
* Mon Dec 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.8.1
  * Fix transformation (rotation, crop, split, ...) of duplicated
    pages
  * Fix some UI glitches
  * Update some translations
  * Set minimum pikepdf version to 1.17.0
  * Fix import of PDF with CropBox
  * Fix clipboard on Wayland
  * Remember window position on screen
  * Fix error with annotations on duplicated pages
* Mon Apr 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.7.1
  * Fix "TypeError: only pages can be inserted" with
    libqpdf >= 10.2.0 & pikepdf < 2.7.0
  * Display imported files in alphabetical order
  * Release memory after rendering and deleting pages
  * Installation instructions for FreeBSD
  * Fix a segfault on "crop white borders" while rendering thumbnails
  * Allow PDF Arranger to be recognized as a handler for all image
    MIME type that it can handle
  * Fix min & max zoom level limits
  * Fix issue with pages copied with ctrl + dnd
  * Fix displayed page range when using paste before
* Mon Feb  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.7.0
  * Allow to edit Keywords, Subjects and dates in document info
  * Ctrl+click now remove a single page from the selection
  * Allow selection of odd or even pages
  * Add option to crop white borders
  * Allow export to individual files
  * Enable autoscroll when rubberband selecting
  * Display the current selection in the status bar
  * Fix import of images with alpha channel
  * Allow to scroll the view with up/down & page up/down keys
  * Allow to zoom to full page
  * Add option to select all pages from same file
  * Fix visual issue in dialogs
  * Improve responsiveness when scrolling zoom levels
  * Change behavior when selecting with shift + click
  * Select a continuous range when drag-selecting
  * Add page scaling
  * Allow to customize keyboard shortcut from the configuration file
  * Add option to select all pages with the same page format
  * Add 'new' button to open new document
  * Support import of encrypted PDF file
  * Allow to insert blank pages
  * Split Page now support n x m split instead of just 1 x 2
  * Reduce memory usage
  * Fix the shortcut created by the Windows MSI installer
  * Problems with editing if not saving after each operation
  * Fix slow paste-interleave-odd/even
* Fri Aug 28 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.6.2. Changes since version 1.5.3:
  * Remove an invalid key from the .desktop file
  * Fix empty string support in the property editor
  * Grey out paste actions if nothing is in the clipboard
  * Improve iconview look and feel
  * Support image file import
  * Ask user confirmation before quit
  * New application icon
  * Insert pages of a PDF at drop location
  * Support page drag and drop on Windows
  * Support Copy/Paste from a file explorer
  * Recommend pikepdf >= 1.15.1
  * Update some translations
- Update description
* Sun Apr 19 2020 Karl Cheng <qantas94heavy@gmail.com>
- Initial build of version 1.5.3
